@@ -8,7 +8,7 @@ SPRWarning <- function (parent, child, error) {
   list(parent, child)
 }
 
-#' Subtree Pruning and Rearrangement (SPR)
+#' Subtree pruning and rearrangement (SPR)
 #'
 #' Perform one \acronym{SPR} rearrangement on a tree
 #' 
@@ -69,6 +69,31 @@ SPR <- function(tree, edgeToBreak = NULL, mergeEdge = NULL) {
   }
 }
 
+#' @rdname SPR
+#' @return `TBRMoves()` returns a list of all trees one SPR move away from
+#'  `tree`, with edges and nodes in preorder, rooted on the first-labelled tip.
+#' @export
+SPRMoves <- function (tree, edgeToBreak = integer(0)) UseMethod('SPRMoves')
+
+#' @rdname SPR
+#' @importFrom TreeTools Preorder RootTree
+#' @export
+SPRMoves.phylo <- function (tree, edgeToBreak = integer(0)) {
+  tree <- Preorder(RootTree(tree, tree$tip.label[1]))
+  edges <- unique(all_spr(tree$edge, edgeToBreak))
+  structure(lapply(edges, function (edg) {
+    tree$edge <- edg
+    tree
+  }), class = 'multiPhylo', tip.label = tree$tip.label)
+}
+
+#' @rdname SPR
+#' @export
+SPRMoves.matrix <- function (tree, edgeToBreak = integer(0)) {
+  tree <- Preorder(RootTree(tree, 1))
+  unique(all_spr(tree, edgeToBreak))
+}
+
 ## TODO Do edges need to be pre-ordered before coming here?
 #' @describeIn SPR faster version that takes and returns parent and child parameters
 #' @template treeParent
@@ -80,7 +105,7 @@ SPR <- function(tree, edgeToBreak = NULL, mergeEdge = NULL) {
 #' @importFrom TreeTools DescendantEdges NonDuplicateRoot
 #' @export
 SPRSwap <- function (parent, child, nEdge = length(parent), nNode = nEdge / 2L,
-                     edgeToBreak=NULL, mergeEdge=NULL) {
+                     edgeToBreak = NULL, mergeEdge = NULL) {
   
   if (nEdge < 5) return (list(parent, child)) #TODO we need to re-root this tree...
   
@@ -144,6 +169,33 @@ SPRSwap <- function (parent, child, nEdge = length(parent), nNode = nEdge / 2L,
 }
 
 
+#' `cSPR()` expects a tree rooted on a single tip. 
+#' @template treeParam
+#' @param whichMove Integer specifying which SPR move index to perform.
+#' @examples 
+#' tree <- TreeTools::BalancedTree(8)
+#' 
+#' # Tree must be rooted on leaf
+#' tree <- TreeTools::RootTree(tree, 1)
+#'
+#' # Random rearrangement
+#' cSPR(tree)
+#'
+#' # Specific rearrangement
+#' cSPR(tree, 9)
+#' @template MRS
+#' @importFrom TreeTools NTip
+#' @export
+cSPR <- function (tree, whichMove = NULL) {
+  edge <- tree$edge
+  if (is.null(whichMove)) whichMove <- sample.int(2147483647L, 1L)
+  tree$edge <- spr(edge, whichMove)
+  
+  # Return:
+  tree
+}
+
+
 #' All SPR trees
 #'
 #' @template treeParent
